==> Pyrogram-0.12.0-py3-none-any.whl: pyrogram/api/functions/contacts/import_contacts.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class ImportContacts(Object):
    """Attributes:
        ID: ``0x2c800be5``

    Args:
        contacts: List of :obj:`InputPhoneContact <pyrogram.api.types.InputPhoneContact>`

    Raises:
        :obj:`RPCError <pyrogram.RPCError>`

    Returns:
        :obj:`contacts.ImportedContacts <pyrogram.api.types.contacts.ImportedContacts>`
    """

    __slots__ = ["contacts"]

    ID = 0x2c800be5
    QUALNAME = "contacts.ImportContacts"

    def __init__(self, *, contacts: list):
        self.contacts = contacts  # Vector<InputContact>

    @staticmethod
    def read(b: BytesIO, *args) -> "ImportContacts":
        # No flags
        
        contacts = Object.read(b)
        
        return ImportContacts(contacts=contacts)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Vector(self.contacts))
        
        return b.getvalue()

==> Pyrogram-0.13.0-py3-none-any.whl: pyrogram/api/functions/contacts/import_contacts.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class ImportContacts(Object):
    """Attributes:
        ID: ``0x2c800be5``

    Parameters:
        contacts: List of :obj:`InputPhoneContact <pyrogram.api.types.InputPhoneContact>`

    Returns:
        :obj:`contacts.ImportedContacts <pyrogram.api.types.contacts.ImportedContacts>`
    """

    __slots__ = ["contacts"]

    ID = 0x2c800be5
    QUALNAME = "functions.contacts.ImportContacts"

    def __init__(self, *, contacts: list):
        self.contacts = contacts  # Vector<InputContact>

    @staticmethod
    def read(b: BytesIO, *args) -> "ImportContacts":
        # No flags
        
        contacts = Object.read(b)
        
        return ImportContacts(contacts=contacts)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Vector(self.contacts))
        
        return b.getvalue()
